@@ -1093,6 +1093,7 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
                     "ColorspaceColorProfileMismatch",name);
               }
             highres=MagickTrue;
+#if !defined(MAGICKCORE_HDRI_SUPPORT) || (MAGICKCORE_QUANTUM_DEPTH > 16)
             {
               const char
                 *artifact;
@@ -1101,6 +1102,7 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
               if (IsStringFalse(artifact) != MagickFalse)
                 highres=MagickFalse;
             }
+#endif
             SetLCMSInfoScale(&source_info,1.0);
             SetLCMSInfoTranslate(&source_info,0.0);
             source_info.colorspace=sRGBColorspace;
@@ -1940,8 +1942,9 @@ static MagickBooleanType ValidateXMPProfile(Image *image,
 static MagickBooleanType ValidateXMPProfile(Image *image,
   const StringInfo *profile,ExceptionInfo *exception)
 {
-  (void) ThrowMagickException(exception,GetMagickModule(),MissingDelegateWarning,
-    "DelegateLibrarySupportNotBuiltIn","'%s' (XML)",image->filename);
+  (void) ThrowMagickException(exception,GetMagickModule(),
+    MissingDelegateWarning,"DelegateLibrarySupportNotBuiltIn","'%s' (XML)",
+    image->filename);
   return(MagickFalse);
 }
 #endif
@@ -2177,7 +2180,7 @@ static MagickBooleanType SyncExifProfile(const Image *image,unsigned char *exif,
   } DirectoryInfo;
 
   DirectoryInfo
-    directory_stack[MaxDirectoryStack];
+    directory_stack[MaxDirectoryStack] = { 0 };
 
   EndianType
     endian;
